/* Bootstrap RTL */
/* Pull right or left */
.pull-right {
	float: left;
}

.pull-left {
	float: right;
}
/* Tables */
.table th,
.table td {
	text-align: right;
}
/* Navbar */
.navbar .brand {
	float: right;
	padding: 8px 20px 8px 12px;
	margin-right: -20px;
	margin-left: 0;
}
.navbar .nav,
.navbar .nav > li {
	float: left;
}
.navbar .nav.pull-right {
	margin-right: 10px;
	margin-left: 0px;
}
.pull-right > .dropdown-menu {
	left: 0;
	right: auto;
}
/* Grid */
[class*="span"] {
	float: right;
	margin-right: 20px;
	margin-left: 0px;
}
.row-fluid [class*="span"] {
	float: right;
	margin-right: 2.127659574%;
	*margin-right: 2.0744680846382977%;
	margin-left: 0px!important;
	*margin-left: 0px!important;
}

.row-fluid [class*="span"]:first-child {
	margin-right: 0;
}
/* Forms */
.form-horizontal .control-label {
	float: right;
	width: auto;
	padding-left: 5px;
	padding-right: 0;
	text-align: right;
}

.form-horizontal .controls {
	*display: inline-block;
	*padding-right: 20px;
	margin-right: 160px;
	*margin-right: 0;
	margin-left: 0;
	text-align: right;
	margin-top: 6px;
}

.form-horizontal .controls:first-child {
	*padding-right: 160px;
}
.form-vertical .controls {
	*display: inline-block;
	*padding-right: 20px;
	margin-right: 0;
	*margin-right: 0;
	margin-left: 0;
	text-align: right;
	margin-top: 6px;
}
.form-vertical .control-label {
	float: none;
	padding-right: 0;
	padding-top: 0;
	text-align: right;
	width: auto;
}
.chzn-container-single-nosearch .chzn-search input {
	position: absolute;
	left: -9000px;
	display:none;
}
/* Nav */
/* Tabs */
.nav-tabs > li,
.nav-pills > li {
	float: right;
}
.nav-stacked > li {
	float: none;
}
/* Buttons */
/* Button Groups */
.btn-group > .btn {
	float: right;
	margin-right: -1px;
	margin-left: 0;
}

.btn-group > .btn:first-child {
	margin-right: 0;
}
.btn-group > .btn:first-child,
.radio.btn-group > label:first-of-type {
	margin-left: 0;
	-webkit-border-bottom-left-radius: 4px;
	border-bottom-left-radius: 4px;
	-webkit-border-top-left-radius: 4px;
	border-top-left-radius: 4px;
	-moz-border-radius-bottomleft: 4px;
	-moz-border-radius-topleft: 4px;
	-webkit-border-bottom-right-radius: 4px;
	border-bottom-right-radius: 4px;
	-webkit-border-top-right-radius: 4px;
	border-top-right-radius: 4px;
	-moz-border-radius-bottomright: 4px;
	-moz-border-radius-topright: 4px;
}

.btn-group > .btn:last-child,
.btn-group > .dropdown-toggle {
	-webkit-border-top-right-radius: 0px;
	border-top-right-radius: 0px;
	-webkit-border-bottom-right-radius: 0px;
	border-bottom-right-radius: 0px;
	-moz-border-radius-topright: 0px;
	-moz-border-radius-bottomright: 0px;
	-webkit-border-top-left-radius: 4px;
	border-top-left-radius: 4px;
	-webkit-border-bottom-left-radius: 4px;
	border-bottom-left-radius: 4px;
	-moz-border-radius-topleft: 4px;
	-moz-border-radius-bottomleft: 4px;
}

.btn-group > .btn.large:first-child {
	-webkit-border-bottom-left-radius: 0px;
	border-bottom-left-radius: 0px;
	-webkit-border-top-left-radius: 0px;
	border-top-left-radius: 0px;
	-moz-border-radius-bottomleft: 0px;
	-moz-border-radius-topleft: 0px;
	margin-right: 0;
	-webkit-border-bottom-right-radius: 6px;
	border-bottom-right-radius: 6px;
	-webkit-border-top-right-radius: 6px;
	border-top-right-radius: 6px;
	-moz-border-radius-bottomright: 6px;
	-moz-border-radius-topright: 6px;
}

.btn-group > .btn.large:last-child,
.btn-group > .large.dropdown-toggle {
	-webkit-border-top-right-radius: 0px;
	border-top-right-radius: 0px;
	-webkit-border-bottom-right-radius: 0px;
	border-bottom-right-radius: 0px;
	-moz-border-radius-topright: 0px;
	-moz-border-radius-bottomright: 0px;
	-webkit-border-top-left-radius: 6px;
	border-top-left-radius: 6px;
	-webkit-border-bottom-left-radius: 6px;
	border-bottom-left-radius: 6px;
	-moz-border-radius-topleft: 6px;
	-moz-border-radius-bottomleft: 6px;
}

.btn-group > .btn:first-child:last-child {
	margin-left: 0;
	-webkit-border-top-left-radius: 4px;
	border-top-left-radius: 4px;
	-webkit-border-bottom-left-radius: 4px;
	border-bottom-left-radius: 4px;
	-moz-border-radius-topleft: 4px;
	-moz-border-radius-bottomleft: 4px;
	-webkit-border-bottom-right-radius: 4px;
	border-bottom-right-radius: 4px;
	-webkit-border-top-right-radius: 4px;
	border-top-right-radius: 4px;
	-moz-border-radius-bottomright: 4px;
	-moz-border-radius-topright: 4px;
}
/* Forms */
/* Input Prepend and Append */
.input-prepend .add-on{
	float: right;
}
.input-append .add-on{
	float: none;
}
.input-prepend .add-on,
.input-prepend .btn {
	margin-left: -1px;
	margin-right: 0;
}

.input-prepend .add-on:first-child,
.input-prepend .btn:first-child {
	-webkit-border-radius: 0 3px 3px 0;
	-moz-border-radius: 0 3px 3px 0;
	border-radius: 0 3px 3px 0;
}

.input-append input,
.input-append select,
.input-append .uneditable-input {
	-webkit-border-radius: 0 3px 3px 0;
	-moz-border-radius: 0 3px 3px 0;
	border-radius: 0 3px 3px 0;
}

.input-append .uneditable-input {
	border-left-color: #ccc;
	border-right-color: #eee;
}

.input-append .add-on:last-child,
.input-append .btn:last-child {
	-webkit-border-radius: 3px 0 0 3px;
	-moz-border-radius: 3px 0 0 3px;
	border-radius: 3px 0 0 3px;
}

.input-prepend.input-append input,
.input-prepend.input-append select,
.input-prepend.input-append .uneditable-input {
	-webkit-border-radius: 0;
	-moz-border-radius: 0;
	border-radius: 0;
}

.input-prepend.input-append .add-on:first-child,
.input-prepend.input-append .btn:first-child {
	margin-left: -1px;
	margin-right: 0px;
	-webkit-border-radius: 0 3px 3px 0;
	-moz-border-radius: 0 3px 3px 0;
	border-radius: 0 3px 3px 0;
	float: right;
}

.input-prepend.input-append .add-on:last-child,
.input-prepend.input-append .btn:last-child {
	margin-right: -1px;
	margin-left: 0px;
	-webkit-border-radius: 3px 0 0 3px;
	-moz-border-radius: 3px 0 0 3px;
	border-radius: 3px 0 0 3px;
}

.input-prepend input,
.input-prepend select,
.input-prepend .uneditable-input {
	-webkit-border-radius: 3px 0 0 3px;
	-moz-border-radius: 3px 0 0 3px;
	border-radius: 3px 0 0 3px;
}


/* start myrtl */
body {
direction:rtl;
}

.pager .next a {
  float: left;
}
.pager .previous a {
  float: right;
}

.icon-arrow-right {
	background-position: -241px -94px;
	float: left;
	padding-right: 3px;
}

.icon-arrow-left {
	background-position: -264px -95px;
}
.icon-refresh {
	background-position: -240px -23px;
}
#refresh-status {
	background-position: right center;
	padding-left: 0;
	padding-right: 25px;
}
.radio input[type="radio"], .checkbox input[type="checkbox"] {
	float: right;
	margin-right: 2px;
	margin-left: 5px;
}

.list-striped, .row-striped {
	list-style: none;
	line-height: 18px;
	text-align: right;
}
.btn-group + .btn-group {
	margin-right: 5px;
	margin-left: 0px;
}
.tabs-left > .nav-tabs {
	float: right;
	margin-left: 19px;
	border-left: 1px solid #DDD;
	margin-right: 0px;
	border-right: 0px;
}
.tabs-left > .nav-tabs .active > a, .tabs-left > .nav-tabs .active > a:hover {
	border-color: #DDD #DDD #DDD transparent;
}
.tabs-left > .nav-tabs > li > a {
	margin-left: -1px;
	-webkit-border-radius: 0 4px 4px 0;
	-moz-border-radius: 0 4px 4px 0;
	border-radius: 0 4px 4px 0;
	margin-right: 0px;
}
.controls > .radio:first-child, .controls > .checkbox:first-child {
	padding-top: 0px;
}
.btn-toolbar {
	margin-top: 14px;
	margin-bottom: 3px;
}
.navbar .nav > li {
	float:right;
}

.icon-folder-2 {
	line-height: 25px;
	padding-left: 5px;
}

.navbar .nav > li > a {
	padding: 8px 10px;
	color: #FFFFFF;
}
.navigation .nav li li .nav-child {
	left: auto;
	right: 100%;

	&:before {
		left: auto;
		right: -7px;
		border-left: 7px solid rgba(0, 0, 0, 0.2);
		border-right-width: 0;
	}
	&:after {
		left: auto;
		right: -6px;
		border-left: 6px solid #ffffff;
		border-right-width: 0;
	}
}
.container-logo {
	padding-top: 6px;
	float: left;
	text-align: left;
}
.modal-header .close {
	float: left;
}
.pagination a {
	float: right;
}
.pagination ul {
	display: inline-block;
	*display: inline;
	/* IE7 inline-block hack */

	*zoom: 1;
	margin-right: 0;
	margin-bottom: 0;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
	-moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
	box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}
.pagination a {
	float: right;
	padding: 0 14px;
	line-height: 34px;
	text-decoration: none;
	border: 1px solid #ddd;
	border-right-width: 0;
}

.pagination li:first-child a {
	border-right-width: 1px;
	-webkit-border-radius: 0 3px 3px 0;
	-moz-border-radius: 0 3px 3px 0;
	border-radius: 0 3px 3px 0;
}
.pagination li:last-child a {
	-webkit-border-radius: 3px 0 0 3px ;
	-moz-border-radius: 3px 0 0 3px;
	border-radius: 3px 0 0 3px;
}
.pagination-centered {
	text-align: center;
}
.pagination-right {
	text-align: right;
}
.icon-first:before {
	content: "\e000";
}
.icon-previous:before {
	content: "\7d";
}
.icon-last:before {
	content: "\7b";
}
.icon-next:before {
	content: "\7c";
}
.dl-horizontal dt {
	float: right;
	text-align: left;
	clear: right;
}
.dl-horizontal dd {
	margin-left: 0;
	margin-right: 180px;
}
.dl-horizontal dt,
.profile> ul {
	margin: 9px 25px 0 0;
}
/* end myrtl */
.dropdown-submenu > a:after {
	float: left;
	border-width: 5px 5px 5px 0;
	margin-left: -10px;
	border-left-color: transparent;
	border-right-color: #CCC;
}
/* Subcategories badge */
.badge {
	margin-left: 10px;
}
/* Align tip text to right */
.tip-text {
	text-align:right;
}
/* Other corrections */
.icon-file-add:before {
	content: "(";
}
.icon-eye-open:before, .icon-eye:before {
	content: ">";
}
.icon-checkin:before, .icon-checkbox:before {
	content: "<";
}
.icon-save-new:before, .icon-plus-2:before {
	content: "[";
}
.btn-toolbar .btn + .btn, .btn-toolbar .btn-group + .btn, .btn-toolbar .btn + .btn-group {
	margin-left: 0;
	margin-right: 5px;
}
.btn-toolbar .btn-wrapper {
  display: inline-block;
  margin: 0 5px 5px 0;
}
.btn-group > .btn + .btn {
	margin-left: 0;
	margin-right: -1px;
}
.input-append .add-on, .input-append .btn, .input-prepend .add-on, .input-prepend .btn {
	margin-left: 0;
	margin-right: -1px;
}
.table-bordered {
	border-right-width: 0;
	border-left-width: 1px;
	border-right-style: none;
	border-left-style: solid;
	border-right-color: -moz-use-text-color;
	border-left-color: #DDDDDD;
}
.chzn-container-single .chzn-single {
	padding-right: 8px;
	padding-left: 0;
}
.chzn-container-single .chzn-single span {
	margin-left: 26px;
	margin-right: 0;
}
.chzn-container-single .chzn-single abbr {
	left: 26px;
	right: auto;
}
.chzn-container-single .chzn-single div {
	left: 0;
	right: auto;
}
.chzn-container-multi .chzn-choices li {
	float: right;
}
.chzn-container-multi .chzn-choices .search-choice {
	margin-right: 5px;
	margin-left: 0;
	padding-right: 5px;
	padding-left: 20px;
}
.chzn-container-multi .chzn-choices .search-choice .search-choice-close {
	left: 3px;
	right: auto;
}
.chzn-container.chzn-with-drop .chzn-drop {
	right: 0;
	left: auto;
}
.chzn-container-single.chzn-container-single-nosearch .chzn-search {
	position: absolute;
	right: -9999px;
	left: auto;
}
.chzn-container .chzn-drop {
	right: -9999px;
	left: auto;
}
.alert {
	padding-right: 14px;
	padding-left: 35px;
}
.alert .close {
	left: -21px;
	right: auto;
}
.close {
	float: left;
}
.form-search .radio, .form-search .checkbox, .form-inline .radio, .form-inline .checkbox {
	margin-bottom: 9px;
}
.form-search .radio input[type="radio"], .form-search .checkbox input[type="checkbox"], .form-inline .radio input[type="radio"], .form-inline .checkbox input[type="checkbox"] {
	float: right;
	margin-left: 3px;
	margin-right: 0;
}
/* Media Manager */
.com_media .container-main .media {
	display: inline-block;
}
.thumbnails > li {
	float: right;
	margin-bottom: 18px;
	margin-right: 20px;
}
#mediamanager-form .description,
#mediamanager-form .filesize,
#mediamanager-form .dimensions {
	direction: ltr;
}
/* Tooltip/Popover */
.popover,
.tooltip-inner {
	text-align: right;
}
.popover.top .arrow,
.popover.bottom .arrow {
	margin-right: -11px;
}
.popover.top .arrow:after,
.popover.bottom .arrow:after {
	margin-right: -10px;
}

/* Media queries */
@media (max-width: 480px) {
	.btn-toolbar .btn-wrapper {
		display: block;
		margin: 0 0 5px 0;
	}
	.btn-toolbar .btn-wrapper .btn {
		margin-left: 0px;
		margin-right: 10px;
	}
}

/*Print pop-up*/
#pop-print {
	float: left;
	margin: 10px;
}

/*url fields*/
#install_url,
#install_directory,
#jform_customurl,
#jform_link,
#jform_params_url,
input[type="url"] {
	text-align: left;
	direction: ltr;
}

/* Menu Module front-end */
#aside .nav .nav-child {
	border-left: 0;
	border-right: 2px solid #ddd;
	padding-left: 0;
	padding-right: 5px;
}

/* Dropdown frontend */
.dropdown-menu {
	text-align: right;
}

/* Icon whitespacing */
[class^="icon-"],
[class*=" icon-"] {
	margin-left: .25em;
}
